use 03728-0001-data.dta, clear

/*
   this extraction program generates the data for the age at first birth models
   use only the year 2002;
   use only women who had had a child, or those who didn't and who are younger than 40
   ==>> these are the censored observations
   This is an example for a variable but known censoring threshold (basic idea:
   the older the latent afb, the more likely is it that an observation is censored)
   What are the modelling options:
 	(1) ols using non-censored observations only;
	(2) cnreg using all observations
*/

keep if sex==2
* women
keep if year==2002
ren childs kids
drop if kids ==.
drop if age ==.
drop if sibs ==.
drop if educ ==.
gen afb = agekdbrn
gen censored = afb==.

replace afb = age if afb==.
drop if afb >= 40


gen city16=(res16>=4)&(res16<=6)
gen lowinc16 = (incom16==1)|(incom16==2)
gen immig = (born ==2)|(parborn==8)
gen white = racecen1 == 1

label var afb "woman's age when 1st child born or afb=age if afb was missing"
label var censored "=1 if afb was missing
label var white "=1 if r's race is white"
label var immig "=1 if respondent or both r's parents born abroad"
label var lowinc16 "=1 if income is below average income at age 16"
label var city16 "=1 if respondent lived in a city (pop>50000) at age 16"

keep year sibs kids age afb educ white city16 lowinc16 immig censored
order afb censored kids age educ year sibs white city16 lowinc16 immig

saveold afb.dta, replace
outsheet using afb.asc, comma nolabel replace






